@@ -31,42 +31,47 @@ class AnimoTorchModelSaver(TorchModelSaver):
             name: module.state_dict() for name, module in modules.items()
         }
 
+        os.makedirs(self.model_path, exist_ok=True)
+
         timestamp = int(time.time_ns()/1000)
         accumulator = self.session.checkpoint_accumulators[behavior_name]
         agent_data =  self.session.agent_datas[behavior_name]
 
-        new_checkpoint = accumulator.OnCheckpointCreated(timestamp, agent_data.Id, self.session.id, agent_data.CurrentRewards)
-        agent_data.AddAndSelectCheckpoint(new_checkpoint)
-        json_checkpoint = Serializer.ToJson(new_checkpoint)
-        json_agent = Serializer.ToJson(agent_data)
-
-        os.makedirs(self.model_path, exist_ok=True)
-
-        # Overwriting recent save files
-        # Save `checkpoint.pt`, this is needed to resume training
-
-        default_pytorch_ckpt_path = os.path.join(self.model_path, DEFAULT_CHECKPOINT_NAME)
-        default_export_ckpt_path = os.path.join(self.model_path, "model") # File format not required by export function
-        default_animo_agent_path = os.path.join(self.model_path, "AgentData.json")
-
-        torch.save(state_dict, default_pytorch_ckpt_path) #type: ignore
-        self.export(default_export_ckpt_path, behavior_name)
-
-        with open(default_animo_agent_path, 'w') as cp_file:
-            cp_file.write(json_agent)
-
-        # Writing historical save files
         checkpoint_path = os.path.join(self.model_path, str(timestamp))
         pytorch_ckpt_path = f"{checkpoint_path}.pt"
         export_ckpt_path = f"{checkpoint_path}.onnx"
-        animo_ckpt_path = f"{checkpoint_path}.json"
 
+        default_pytorch_ckpt_path = os.path.join(self.model_path, DEFAULT_CHECKPOINT_NAME)
+        default_export_ckpt_path = os.path.join(self.model_path, "model") # File format not required by export function
+        
+        # Overwriting recent save files
+        # Save `checkpoint.pt`, this is needed to resume training
+        torch.save(state_dict, default_pytorch_ckpt_path) #type: ignore
+        self.export(default_export_ckpt_path, behavior_name)
+
+        # Writing historical save files
         torch.save(state_dict, pytorch_ckpt_path) #type: ignore
         self.export(checkpoint_path, behavior_name)
 
-        with open(animo_ckpt_path, 'w') as cp_file:
-            cp_file.write(json_checkpoint)
+        # Writing AnimoData and AnimoCheckpoint
+        new_checkpoint = accumulator.OnCheckpointCreated(timestamp, agent_data.Id, self.session.id, agent_data.CurrentRewards)
 
-        print(f"Animo-Learn::Checkpoint::{self.session.id}::{checkpoint_path}")
+        if new_checkpoint:
+            agent_data.AddAndSelectCheckpoint(new_checkpoint)
+            json_checkpoint = Serializer.ToJson(new_checkpoint)
+            json_agent = Serializer.ToJson(agent_data)
 
-        return export_ckpt_path, [pytorch_ckpt_path, animo_ckpt_path]
+            default_animo_agent_path = os.path.join(self.model_path, "AgentData.json")
+            animo_ckpt_path = f"{checkpoint_path}.json"
+
+            with open(default_animo_agent_path, 'w') as cp_file:
+                cp_file.write(json_agent)
+
+            with open(animo_ckpt_path, 'w') as cp_file:
+                cp_file.write(json_checkpoint)
+
+            print(f"Animo-Learn::Checkpoint::{self.session.id}::{checkpoint_path}")
+            return export_ckpt_path, [pytorch_ckpt_path, animo_ckpt_path]
+        else:
+            print(f"Animo-Learn::Error::Accumulator did not return new checkpont")
+            return export_ckpt_path, [pytorch_ckpt_path]
\ No newline at end of file
